@@ -101,7 +101,21 @@ static const char *role_names [] =
   "fooler",
   "paragraph",
   "ruler",
-  "application"
+  "application",
+  "autocomplete",
+  "editbar",
+  "embedded",
+  "entry",
+  "chart",
+  "caption",
+  "document_frame",
+  "heading",
+  "page",
+  "section",
+  "form",
+  "redundant object",
+  "link",
+  "input method window"
 };
 
 #define MAX_ROLES (sizeof (role_names) / sizeof (char *))
@@ -191,6 +205,17 @@ cspi_init_role_table (AccessibleRole *role_table)
   role_table [Accessibility_ROLE_AUTOCOMPLETE] = SPI_ROLE_AUTOCOMPLETE;
   role_table [Accessibility_ROLE_EDITBAR] = SPI_ROLE_EDITBAR;
   role_table [Accessibility_ROLE_EMBEDDED] = SPI_ROLE_EMBEDDED;
+  role_table [Accessibility_ROLE_ENTRY] = SPI_ROLE_ENTRY;
+  role_table [Accessibility_ROLE_CHART] = SPI_ROLE_CHART;
+  role_table [Accessibility_ROLE_CAPTION] = SPI_ROLE_CAPTION;
+  role_table [Accessibility_ROLE_DOCUMENT_FRAME] = SPI_ROLE_DOCUMENT_FRAME;
+  role_table [Accessibility_ROLE_HEADING] = SPI_ROLE_HEADING;
+  role_table [Accessibility_ROLE_PAGE] = SPI_ROLE_PAGE;
+  role_table [Accessibility_ROLE_SECTION] = SPI_ROLE_SECTION;
+  role_table [Accessibility_ROLE_FORM] = SPI_ROLE_FORM;
+  role_table [Accessibility_ROLE_REDUNDANT_OBJECT] = SPI_ROLE_REDUNDANT_OBJECT;
+  role_table [Accessibility_ROLE_LINK] = SPI_ROLE_LINK;
+  role_table [Accessibility_ROLE_INPUT_METHOD_WINDOW] = SPI_ROLE_INPUT_METHOD_WINDOW;
 
   return TRUE;
 }
@@ -217,7 +242,7 @@ cspi_role_from_spi_role (Accessibility_Role role)
   return cspi_role; 
 }
 
-static AccessibleAttributeSet *
+AccessibleAttributeSet *
 cspi_attribute_set_from_sequence (const Accessibility_AttributeSet *seq)
 {
     AccessibleAttributeSet *set = g_new0 (AccessibleAttributeSet, 1);
@@ -605,7 +630,7 @@ Accessible_getAttributes (Accessible *obj)
     retval = cspi_attribute_set_from_sequence (corba_seq);
     CORBA_free (corba_seq);
 
-    return NULL;
+    return retval;
 }
 
 /**
@@ -681,6 +706,22 @@ Accessible_isComponent (Accessible *obj)
 			      "IDL:Accessibility/Component:1.0");
 }
 
+/**
+ * Accessible_isDocument:
+ * @obj: a pointer to the #Accessible instance to query.
+ *
+ * Query whether the specified #Accessible implements #AccessibleDocument.
+ *
+ * Returns: #TRUE if @obj implements the #AccessibleDocument interface,
+ *          #FALSE otherwise.
+ **/
+SPIBoolean
+Accessible_isDocument (Accessible *obj)
+{
+  return cspi_accessible_is_a (obj,
+			      "IDL:Accessibility/Document:1.0");
+}
+
 /**
  * Accessible_isEditableText:
  * @obj: a pointer to the #Accessible instance to query.
@@ -857,6 +898,21 @@ Accessible_getComponent (Accessible *obj)
   return (AccessibleComponent *) Accessible_queryInterface (
 	  obj, "IDL:Accessibility/Component:1.0");
 }
+/**
+ * Accessible_getDocument:
+ * @obj: a pointer to the #Accessible instance to query.
+ *
+ * Get the #AccessibleDocument interface for an #Accessible.
+ *
+ * Returns: a pointer to an #AccessibleDocument interface instance, or
+ *          NULL if @obj does not implement #AccessibleDocument.
+ **/
+AccessibleDocument *
+Accessible_getDocument (Accessible *obj)
+{
+  return (AccessibleDocument *) Accessible_queryInterface (
+	  obj, "IDL:Accessibility/Document:1.0");
+}
 
 /**
  * Accessible_getEditableText:
@@ -1089,6 +1145,9 @@ cspi_init_relation_type_table (AccessibleRelationType *relation_type_table)
   relation_type_table [Accessibility_RELATION_EMBEDS] = SPI_RELATION_EMBEDS;
   relation_type_table [Accessibility_RELATION_EMBEDDED_BY] = SPI_RELATION_EMBEDDED_BY;
   relation_type_table [Accessibility_RELATION_POPUP_FOR] = SPI_RELATION_POPUP_FOR;
+  relation_type_table [Accessibility_RELATION_PARENT_WINDOW_OF] = SPI_RELATION_PARENT_WINDOW_OF;
+  relation_type_table [Accessibility_RELATION_DESCRIBED_BY] = SPI_RELATION_DESCRIBED_BY;
+  relation_type_table [Accessibility_RELATION_DESCRIPTION_FOR] = SPI_RELATION_DESCRIPTION_FOR;
   return TRUE;
 }
 
@@ -1250,6 +1309,13 @@ spi_state_to_corba (AccessibleState state)
       MAP_STATE (VISIBLE);
       MAP_STATE (MANAGES_DESCENDANTS);
       MAP_STATE (INDETERMINATE);
+      MAP_STATE (TRUNCATED);
+      MAP_STATE (REQUIRED);
+      MAP_STATE (INVALID_ENTRY);
+      MAP_STATE (SUPPORTS_AUTOCOMPLETION);
+      MAP_STATE (SELECTABLE_TEXT);
+      MAP_STATE (IS_DEFAULT);
+      MAP_STATE (VISITED);
     default:
       return Accessibility_STATE_INVALID;
   }
