@@ -21,6 +21,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <glib/gmessages.h>
 #include <glib/gslist.h>
 #include <Accessibility.h>
@@ -36,6 +37,8 @@ static GSList *working_list = NULL; /* of Iteration */
 
 static char *spi_atk_bridge_null_string = "";
 
+Accessibility_Role spi_accessible_role_from_atk_role (AtkRole role);
+
 Accessibility_Role
 spi_role_from_atk_role (AtkRole role)
 {
